@@ -10,25 +10,32 @@ describe 'nova::compute::libvirt' do
 
       it { is_expected.to contain_class('nova::params')}
 
-      it { is_expected.to contain_package('nova-compute-kvm').with(
-        :ensure => 'present',
-        :before => 'Package[nova-compute]',
-        :tag    => ['openstack']
-      ) }
+      it {
+        is_expected.to contain_package('nova-compute-kvm').with(
+          :ensure => 'present',
+          :tag    => ['openstack', 'nova-package']
+        )
+        is_expected.to contain_package('nova-compute-kvm').that_requires('Anchor[nova::install::begin]')
+        is_expected.to contain_package('nova-compute-kvm').that_notifies('Anchor[nova::install::end]')
+      }
 
-      it { is_expected.to contain_package('libvirt').with(
-        :name   => 'libvirt-bin',
-        :ensure => 'present'
-      ) }
+      it {
+        is_expected.to contain_package('libvirt').with(
+          :name   => 'libvirt-bin',
+          :ensure => 'present'
+        )
+        is_expected.to contain_package('libvirt').that_requires('Anchor[nova::install::begin]')
+        is_expected.to contain_package('libvirt').that_comes_before('Anchor[nova::install::end]')
+      }
 
-      it { is_expected.to contain_service('libvirt').with(
-        :name     => 'libvirt-bin',
-        :enable   => true,
-        :ensure   => 'running',
-        :provider => 'upstart',
-        :require  => 'Package[libvirt]',
-        :before   => ['Service[nova-compute]']
-      )}
+      it {
+        is_expected.to contain_service('libvirt').with(
+          :name     => 'libvirt-bin',
+          :enable   => true,
+          :ensure   => 'running',
+          :provider => 'upstart',
+        )
+      }
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
@@ -38,7 +45,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
-      it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_kernels').with_ensure('absent')}
@@ -47,11 +54,13 @@ describe 'nova::compute::libvirt' do
 
     describe 'with params' do
       let :params do
-        { :libvirt_virt_type                          => 'qemu',
+        { :ensure_package                             => 'latest',
+          :libvirt_virt_type                          => 'qemu',
           :vncserver_listen                           => '0.0.0.0',
           :libvirt_cpu_mode                           => 'host-passthrough',
           :libvirt_cpu_model                          => 'kvm64',
           :libvirt_disk_cachemodes                    => ['file=directsync','block=none'],
+          :libvirt_hw_disk_discard                    => 'unmap',
           :remove_unused_base_images                  => true,
           :remove_unused_kernels                      => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
@@ -61,23 +70,29 @@ describe 'nova::compute::libvirt' do
         }
       end
 
+      it { is_expected.to contain_package('nova-compute-qemu').with(
+        :name   => 'nova-compute-qemu',
+        :ensure => 'latest'
+      ) }
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.FoobarDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-passthrough')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
-      it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('0.0.0.0')}
+      it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
+      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_kernels').with_value(true)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
-      it { is_expected.to contain_service('libvirt').with(
-        :name     => 'custom_service',
-        :enable   => true,
-        :ensure   => 'running',
-        :require  => 'Package[libvirt]',
-        :before   => ['Service[nova-compute]']
-      )}
+      it {
+        is_expected.to contain_service('libvirt').with(
+          :name     => 'custom_service',
+          :enable   => true,
+          :ensure   => 'running',
+          :before   => ['Service[nova-compute]']
+        )
+      }
     end
 
     describe 'with custom cpu_mode' do
@@ -99,7 +114,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('0.0.0.0')}
+        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => 'libvirtd_opts="-d -l"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -114,7 +129,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('::0')}
+        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => 'libvirtd_opts="-d -l"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -164,7 +179,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_package('libvirt-nwfilter').with(
         :name   => 'libvirt-daemon-config-nwfilter',
         :ensure => 'present',
-        :before  => 'Service[libvirt]',
+        :before  => ['Service[libvirt]', 'Anchor[nova::install::end]'],
       ) }
 
       it { is_expected.to contain_service('libvirt').with(
@@ -172,8 +187,7 @@ describe 'nova::compute::libvirt' do
         :enable   => true,
         :ensure   => 'running',
         :provider => 'init',
-        :require  => 'Package[libvirt]',
-        :before   => ['Service[nova-compute]']
+        :before   => ['Service[nova-compute]'],
       )}
       it { is_expected.to contain_service('messagebus').with(
         :ensure   => 'running',
@@ -192,11 +206,11 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_service('libvirt').with(
-          :provider => nil
+          :provider => 'redhat'
         )}
 
         it { is_expected.to contain_service('messagebus').with(
-          :provider => nil,
+          :provider => 'redhat',
           :name     => 'dbus'
         )}
       end
@@ -206,7 +220,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
-      it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_kernels').with_ensure('absent')}
@@ -225,7 +239,7 @@ describe 'nova::compute::libvirt' do
       end
 
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
-      it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('0.0.0.0')}
+      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_kernels').with_value(true)}
@@ -245,7 +259,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('0.0.0.0')}
+        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -260,7 +274,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('::0')}
+        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -294,7 +308,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_package('libvirt-nwfilter').with(
         :name   => 'libvirt-daemon-config-nwfilter',
         :ensure => 'present',
-        :before  => 'Service[libvirt]',
+        :before  => ['Service[libvirt]', 'Anchor[nova::install::end]'],
       ) }
 
       it { is_expected.to contain_service('libvirt').with(
@@ -302,24 +316,23 @@ describe 'nova::compute::libvirt' do
         :enable   => true,
         :ensure   => 'running',
         :provider => nil,
-        :require  => 'Package[libvirt]',
         :before   => ['Service[nova-compute]']
       )}
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
-      it { is_expected.to contain_nova_config('DEFAULT/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
     end
 
   end
 
   context 'on Debian platforms' do
     let (:facts) do
-      {
+      @default_facts.merge({
         :osfamily => 'Debian',
         :operatingsystem => 'Debian',
         :os_package_family => 'debian'
-      }
+      })
     end
 
     it_behaves_like 'debian-nova-compute-libvirt'
@@ -327,11 +340,11 @@ describe 'nova::compute::libvirt' do
 
   context 'on Debian platforms' do
     let (:facts) do
-      {
+      @default_facts.merge({
         :osfamily => 'Debian',
         :operatingsystem => 'Ubuntu',
         :os_package_family => 'ubuntu'
-      }
+      })
     end
 
     it_behaves_like 'debian-nova-compute-libvirt'
@@ -339,10 +352,10 @@ describe 'nova::compute::libvirt' do
 
   context 'on RedHat platforms' do
     let (:facts) do
-      {
+      @default_facts.merge({
         :osfamily => 'RedHat',
         :os_package_type => 'rpm'
-      }
+      })
     end
 
     it_behaves_like 'redhat-nova-compute-libvirt'
